@@ -73,7 +73,7 @@ from types import GeneratorType, ModuleType
 from collections import deque
 from binascii import a2b_hex, b2a_hex
 
-VERSION = '0.09'
+VERSION = '0.10'
 
 PYTHON3 = sys.version_info >= (3, 0)
 if PYTHON3:
@@ -639,21 +639,28 @@ class _GlobalProxy:
         self._client = client
         self._name = name
 
-    @property
-    def value(self):
-        return self._client.send_request(0, 'get_global', (self._name,))
- 
-    @value.setter
-    def value(self, newval):
-        self._client.send_request(0, 'set_global', (self._name, newval))
-        return newval
+    def __getattribute__(self, name):
+        ## Using a @property and having a fallback __getattr__ does not work as
+        ## expected: if the remote call raises an AttributeError, it will be
+        ## ignored and __getattr__ will be called instead.
 
-    def __getattr__(self, name):
-        return _GlobalProxy(self._client, '%s.%s' % (self._name, name))
+        if name == 'value':
+            return self._client.send_request(0, 'get_global', (self._name,))
+        try:
+            return object.__getattribute__(self, name)
+        except AttributeError:
+            return _GlobalProxy(self._client, self._name + '.' + name)
+
+    def __setattribute__(self, name, newval):
+        if name == 'value':
+            self._client.send_request(0, 'set_global', (self._name, newval))
+            return newval
+        return object.__setattribute__(self, name, newval)
     
     def __call__(self, *args, **kw):
         return self._client.raw_call(self._name, args, kw, *_get_special_keywords(kw))
 
+
 class Client(Connection):
     '''Represents the client side of the connection. '''
 
@@ -1467,9 +1474,10 @@ _add_extra_classes()
 del _add_extra_classes
 
 if sys.platform.startswith('win'):
-    from ctypes import windll, WinError
+    from ctypes import windll, WinError, wintypes
     kernel32 = windll.kernel32
     SetHandleInformation = kernel32.SetHandleInformation
+    SetHandleInformation.argtypes = [wintypes.HANDLE, wintypes.DWORD, wintypes.DWORD]
 
     def _write_key_file(path, key):
         '''Write an HMAC key to a file. Returns True if the file was created, or
