@@ -34,6 +34,16 @@ import easycluster as _core
 from collections import deque
 from types import ModuleType
 
+## Stolen from multiprocessing. We can't just use multiprocessing -- it has way
+## too many weird bugs on Windows.
+
+WINSERVICE = sys.executable.lower().endswith("pythonservice.exe")
+
+if WINSERVICE:
+    _python_exe = os.path.join(sys.exec_prefix, 'python.exe')
+else:
+    _python_exe = sys.executable
+
 __all__ = ['Server', 'QuietServer', 'run_server', 'spawn_local']
 __metaclass__ = type
 
@@ -561,7 +571,7 @@ if sys.platform.startswith('win'):
     from ctypes import (windll, Structure, Union, c_size_t, c_int,
                         py_object, POINTER, pythonapi, create_string_buffer, WinError)
 
-    import multiprocessing
+    import subprocess
 
     # Windows does not support "inheriting" sockets; the only way to
     # pass an open socket to another process is to use the
@@ -640,44 +650,31 @@ if sys.platform.startswith('win'):
             WSAclose(rfd)
             return sock
     
-    class RunnerProcess(multiprocessing.Process):
-        def __init__(self, sockinfo, peername, svrclass, key):
-            multiprocessing.Process.__init__(self)
-            self.sockinfo = sockinfo
-            self.peername = peername
-            self.svrclass = svrclass
-            self.key = key
-            self.daemon = True
+    MAGIC_ARG = '--easycluster-run-server'
 
-        def run(self):
-            pinfo, family, type, proto = self.sockinfo.recv()
-            self.sockinfo.close()
+    def spawn_runner_process(csock, peername, svrclass, key):
+        args = [_python_exe, '-m', 'easycluster.__main__', MAGIC_ARG]
+        p = subprocess.Popen(args, stdin=subprocess.PIPE)
+        pinfo = dupsock(csock, p.pid)
+        p.stdin.write(_core.b2a_hex(
+                _core.pickle.dumps((pinfo, csock.family, csock.type,
+                                    csock.proto, peername, svrclass, key),
+                                   protocol=_core.pickle.HIGHEST_PROTOCOL)) + b'\r\n')
+        p.stdin.close()
+
+    def server_check_runner():
+        if len(sys.argv) == 2 and sys.argv[1] == MAGIC_ARG:
+            pinfo, family, type, proto, peername, svrclass, key = _core.pickle.loads(_core._hexdec(sys.stdin.readline().strip()))
             sys.stdin.close()
             sock = make_socket(family, type, proto, pinfo)
             try:
-                self.svrclass(self.key, sock, self.peername).run()
+                svrclass(key, sock, peername).run()
             except Exception:
                 traceback.print_exc()
             sys.exit(0)
-
-    def spawn_runner_process(csock, peername, svrclass, key):
-        rpipe, wpipe = multiprocessing.Pipe(False)
-        runner = RunnerProcess(rpipe, peername, svrclass, key)
-        runner.start()
-        pinfo = dupsock(csock, runner.ident)
-        wpipe.send((pinfo, csock.family, csock.type, csock.proto))
-        wpipe.close()
-                
-    def server_check_runner():
-        pass
                 
     def server_init():
-        ## Work around a bug in multiprocessing
-        mainmod = sys.modules.get('__main__')
-        if mainmod:
-            fil = getattr(mainmod, '__file__', '')
-            if fil.endswith('__main__.py'):
-                mainmod.__file__ = fil[:-11] + '__init__.py'
+        pass
 
     _daemonize = None
 
